import React, { useState } from "react";
import { Grommet, Box, ResponsiveContext, Grid } from "grommet";
import theme from "../style/Theme";
import PageHeader from "./PageHeader";
import SideMenu from "./SideMenu";
import InstanceView from "./InstanceView";
import TemplateView from "./TemplateView";

function App() {
  const [showSideBar, setShowSideBar] = useState(false);

  return (
    <Grommet theme={theme} full>
      <ResponsiveContext.Consumer>
        {size => (
          <Box fill>
            <PageHeader
              showSideBar={showSideBar}
              setShowSideBar={setShowSideBar}
            />
            <Box direction="row" flex overflow={{ horizontal: "hidden" }}>
              <SideMenu
                showSideBar={showSideBar}
                setShowSideBar={setShowSideBar}
              />
              <Grid
                areas={[
                  { name: "instances", start: [0, 0], end: [0, 0] },
                  { name: "templates", start: [1, 0], end: [1, 0] }
                ]}
                columns={["flex", "flex"]}
                rows={["flex"]}
                gap="small"
                margin="small"
              >
                <Box gridArea="instances">
                  <InstanceView size={size} />
                </Box>
                <Box gridArea="templates">
                  <TemplateView size={size} />
                </Box>
              </Grid>
            </Box>
          </Box>
        )}
      </ResponsiveContext.Consumer>
    </Grommet>
  );
}

export default App;
