import React, { useEffect, useState } from "react";
import { Box, Heading, Button } from "grommet";
import { Card } from "grommet-controls";
import LoadingWrapper from "./LoadingWrapper";
import { ChapterAdd } from "grommet-icons";

const InstanceView = () => {
  const [data, setData] = useState([]);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    setIsLoading(true);
    fetch("http://vm.niif.cloud.bme.hu:20778/api/v1/instances/")
      .then(response => response.json())
      .then(json => setData(json))
      .then(() => setIsLoading(false));
  }, []);

  return (
    <LoadingWrapper loading={isLoading}>
      <Box margin="small" justify="evenly" align="center">
        <Heading margin="small">Virtual Machines</Heading>
        <Button
          icon={<ChapterAdd />}
          label="Start a new VM"
          size="xlarge"
          primary
          color="darkbrand"
        />
      </Box>
      <Box flex direction="row" wrap justify="evenly">
        {data.map(e => (
          <Card
            background="brand"
            basis="medium"
            margin="small"
            animation={{ type: "zoomIn", duration: 1000, size: "xlarge" }}
            elevation="medium"
            pad="medium"
            border={{ size: "none" }}
          >
            <Card.CardTitle>{e.name}</Card.CardTitle>
            <Card.CardContent>{e.name}</Card.CardContent>
          </Card>
        ))}
      </Box>
    </LoadingWrapper>
  );
};

export default InstanceView;
